aboutsummaryrefslogtreecommitdiff
path: root/errhandlers
diff options
context:
space:
mode:
authorVidhu Kant Sharma <vidhukant@protonmail.ch>2022-02-17 21:47:32 +0530
committerVidhu Kant Sharma <vidhukant@protonmail.ch>2022-02-17 21:47:32 +0530
commit69a454a9a8430164c2ce798ecafee221404c50ec (patch)
treeff2856a66742f54a3cf9508181fbe1997d2870e6 /errhandlers
parent8824c264c6d4230d353546ee69036ad41d4ec8cc (diff)
Fixed import errors in errhandlers package
Diffstat (limited to 'errhandlers')
-rw-r--r--errhandlers/errhandlers.go4
-rw-r--r--errhandlers/validators.go2
2 files changed, 3 insertions, 3 deletions
diff --git a/errhandlers/validators.go b/errhandlers/validators.go
index 1be61cb..4e4137d 100644
--- a/errhandlers/validators.go
+++ b/errhandlers/validators.go
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
diff --git a/errhandlers/errhandlers.go b/errhandlers/errhandlers.go
index a9f8054..59a45ae 100644
--- a/errhandlers/errhandlers.go
+++ b/errhandlers/errhandlers.go
@@ -1,4 +1,4 @@
/* mal2go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@ package errhandlers
import (
"errors"
"fmt"
- "github.com/MikunoNaka/mal2go/util"
+ "github.com/MikunoNaka/MAL2Go/util"
)
// if fields aren't specified
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify